@@ -14,7 +14,7 @@ class PdpService:
 
     def __init__(self, pdpRepo:PdpRepo):
         self.__pdpRepo = pdpRepo
-        self.__logger = Logger(child=True)
+        self.__logger = Logger()
 
     def __evaluateResourceOperation(self, resourceOperation:ResourceOperation, 
             subjectUris:List[str], resourcePolicy:Policy, 
